# langchain-asteroid

This package contains the LangChain integration with Asteroid

## Installation

```bash
pip install -U langchain-asteroid
```

And you should configure credentials by setting the following environment variables:

* TODO: fill this out

## Chat Models

`ChatAsteroid` class exposes chat models from Asteroid.

```python
from langchain_asteroid import ChatAsteroid

llm = ChatAsteroid()
llm.invoke("Sing a ballad of LangChain.")
```

## Embeddings

`AsteroidEmbeddings` class exposes embeddings from Asteroid.

```python
from langchain_asteroid import AsteroidEmbeddings

embeddings = AsteroidEmbeddings()
embeddings.embed_query("What is the meaning of life?")
```

## LLMs
`AsteroidLLM` class exposes LLMs from Asteroid.

```python
from langchain_asteroid import AsteroidLLM

llm = AsteroidLLM()
llm.invoke("The meaning of life is")
```
